<?php 
/**
* $Id: googlereader.php 02 2013-03-27 10:46:43Z webgift $
* @version 1.0
* @package: Google Docs Viewer bot
* @author: WebGift Web Services (Stavros Stratakis)
* @email: info@webgift.gr
* @link: http://www.webgift.gr
* @license: Creative Commons 3.0 Share Alike
* @copyright: (C) 2007-2011 Webgift Web Services. All rights reserved.
* @description: The Google Docs Viewer bot allows you to quickly view many file types online, including PDFs, Microsoft Office files, and many image file types. It also allows you to create a link that allows other people to view your document quickly and easily in any browser. You can directly access the Google Docs Viewer at http://docs.google.com/viewer. Highslide technology is included!
*/

defined('_VALID_MOS') or die('Direct Access to this location is not allowed.');

if (!class_exists('googlereader')) {
	class googlereader {
		
		private $ssl = false;
		

		/****************************/
		/* GET SECURE LIVE SITE URL */
		/****************************/
		private function secureLive() {
			global $mainframe;

			if (defined('GREADER_SSL_LIVE_SITE')) { return GREADER_SSL_LIVE_SITE; }
			$this->ssl = false;
			if (isset($_SERVER['HTTPS'])) {
				if (($_SERVER['HTTPS'] == 'on') || ($_SERVER['HTTPS'] == 1)) {
					$this->ssl = true;
				}
			} else if (isset($_SERVER['SERVER_PORT']) && ($_SERVER['SERVER_PORT'] == 443)) {
				$this->ssl = true;
			}

			if ($this->ssl === true) {
				$ssllive = preg_replace('/^(http\:)/i', 'https:', $mainframe->getCfg('live_site'));
				define('GREADER_SSL_LIVE_SITE', $ssllive);
			} else {
				define('GREADER_SSL_LIVE_SITE', $mainframe->getCfg('live_site'));
			}
			return GREADER_SSL_LIVE_SITE;
		}


		/********************/
		/* LOAD FRONT IMAGE */
		/********************/    
        private function loadImage(){
            global $lang;
            switch ($lang){
                case 'greek':
                $imageb = $this->secureLive().'/mambots/content/googlereader/book_readel.png';
                break;
                default:
                $imageb = $this->secureLive().'/mambots/content/googlereader/book_readen.png';
                break;
            }            
            
            return $imageb;
        }


		/**********************************/
		/* IMPORT EASY GALLERY JS AND CSS */
		/**********************************/
		private function loadJSCSS() {
			global $mainframe;
            $js = '';
            $graphdir = $this->secureLive().'/mambots/content/googlereader/graphics/';

			if (defined('GREADER_LOADED')) { return; }
			$boturl = $this->secureLive().'/mambots/content/googlereader';
			$mainframe->addCustomHeadTag('<script type="text/javascript" src="'.$boturl.'/highslide-with-html.js"></script>');
            $mainframe->addCustomHeadTag('<link href="'.$boturl.'/highslide.css" rel="stylesheet" type="text/css" />');
            $js .= "\n\t".'/* <![CDATA[ */'."\n";
            $js .= "\t"."hs.graphicsDir = '".$graphdir."';"."\n";
            $js .= "\t"."hs.outlineType = 'rounded-white';"."\n";
            $js .= "\t"."hs.align = 'center';"."\n";
            $js .= "\t"."hs.wrapperClassName = 'draggable-header';"."\n";
            $js .= "\t"."hs.showCredits = false;"."\n";
            $js .= "\t".' /* ]]> */'."\n";
            $mainframe->addCustomHeadTag('<script type="text/javascript">'.$js.'</script>');
			define('GREADER_LOADED', 1);
        }
        
                
		/**********************/
		/* GET LOCAL DOCUMENT */
		/**********************/        
        private function getDOC($url=''){
            $boturl = $this->secureLive().'/images/userfiles/'.$url;
            return $boturl;
        }
        
        
		/*****************************/
		/* CHECK LOCAL FILE IF EXIST */
		/*****************************/         
        private function checkFile($url=''){
            global $mainframe;
            
            if(!file_exists($mainframe->getCfg('absolute_path').'/images/userfiles/'.$url)){
                $error_msg = '<span style="font-weight:bold;color:#dd0000;">Error Google Viewers Bot</span><br />There is no file :<strong>'.$url.'</strong> at folder : <strong>images/userfiles/</strong>';
            }
            
            return $error_msg;
                        
        }
        
        
		/******************************/
		/* CHECK SUPPORTED FILE TYPES */
		/******************************/          
        private function checkFileType($url=''){
            $sftypes = array('doc', 'docx', 'xls', 'xlsx', 'ppt', 'pptx', 'pdf', 'pages', 'ai', 'psd', 'tiff', 'dxf', 'svg', 'esp', 'ps', 'ttf', 'xps', 'zip', 'rar');

            $parts = preg_split('/\./', $url, 2, PREG_SPLIT_NO_EMPTY);
            if ($parts && is_array($parts) && (count($parts) > 0)) {
                if(!in_array($parts[1], $sftypes)){
                    $error_msg = '<span style="font-weight:bold;color:#dd0000;">Error Google Viewers Bot</span><br />Not supported file type : <strong>'.$parts[1].'</strong> at file name: <strong>'.$parts[0].'</strong>'; 
                }
            }
            
            return $error_msg;            
        }


		/******************/
		/* RUN FOREST RUN */
		/******************/          
        public function run(&$url, $param=array()){
            $dismode = $param['dismode'];
            $ifwidth = $param['ifwidth'];
            $ifheight = $param['ifheight'];
            $error_msg = '';
            
            if($ifwidth <= 50){$ifwidth = 150;}
            if($ifheight <= 50){$ifheight = 200;}
            
            $cond = preg_match('|^http(s)?://[a-z0-9-]+(.[a-z0-9-]+)*(:[0-9]+)?(/.*)?$|i', $url);
            
            if ( $cond == 0 ){
                $error_msg = $this->checkFileType($url);
                if($error_msg == ''){$error_msg = $this->checkFile($url);}
                
                //replace unsupported chars with space
                $pat = "#([\']|[\"]|[\$]|[\#]|[\<]|[\>]|[\*]|[\%]|[\~]|[\`]|[\^]|[\|]|[\{]|[\}]|[\\\])#";
                $url = preg_replace($pat, '', $url);
                $url_local = $this->getDOC($url);
                $url_encoded = trim(urlencode($url_local));
            
            } else {
                $url_encoded = trim(urlencode($url));    
            }
            
            $outlink = ($this->ssl === true) ? 'https://docs.google.com/viewer?url='.$url_encoded.'&embedded=true' : 'http://docs.google.com/viewer?url='.$url_encoded.'&embedded=true';
            
            if($error_msg == ''){
                if($dismode == 0){
                    $this->loadJSCSS();
                    $imageurl = $this->loadImage();
                    $type = "'iframe'";
                    $align = "'center'";
                    $html = '<a href="'.$outlink.'" onclick="return hs.htmlExpand(this, {align: '.$align.', width:'.$ifwidth.' , height:'.$ifheight.' , objectType:  '.$type.'})"><img width="178" height="48" title="'._READ_MORE.'" src="'.$imageurl.'" /></a>';
                }else{
                    $html = '<iframe src="'.$outlink.'" style="width:'.$ifwidth.'px; height:'.$ifheight.'px;" frameborder="0"></iframe>';
                }
            }else{
                $html = $error_msg;
            }

           return $html;
        }
        
        
	}
}


/**********************/
/* CALL BACK REPLACER */
/**********************/
function botGoogleReader($published, &$row, $params, $page=0) {
    global $database, $_MAMBOTS, $mainframe;

    $regex = "#{gviewer\s*.*?}(.*?){/gviewer}#s";
    if (!$published) {
    	$row->text = preg_replace($regex, '', $row->text);
    	return;
    }
    
	if (strpos($row->text, 'gviewer' ) === false) { return true; }
    
	$matches = array();
	preg_match_all($regex, $row->text, $matches, PREG_PATTERN_ORDER);

	if ($matches) {
		if (!isset($_MAMBOTS->_content_bot_params['googlereader'])) {
			$database->setQuery("SELECT params FROM #__mambots WHERE element = 'googlereader' AND folder = 'content'", '#__', 1, 0);
			$database->loadObject($mambot);
			$botParams = new mosParameters($mambot->params);
			$_MAMBOTS->_content_bot_params['googlereader']['dismode'] = (int)$botParams->get('dismode', 0);
            $_MAMBOTS->_content_bot_params['googlereader']['ifwidth'] = (int)$botParams->get('ifwidth', 600);
            $_MAMBOTS->_content_bot_params['googlereader']['ifheight'] = (int)$botParams->get('ifheight', 500);
			unset($mambot, $botParams);
		}
        $i=0;
        foreach ($matches[0] as $match) {
            $gr = new googlereader();
            $html = $gr->run($matches[1][$i], $_MAMBOTS->_content_bot_params['googlereader']);
            $i++;
            unset($gr);
            $row->text = preg_replace("#".$match."#", $html, $row->text);
        }
        
	}
    
	return true;
}

$_MAMBOTS->registerFunction('onPrepareContent', 'botGoogleReader');

?>